==> wpewebkit_2.38.5.orig.tar.xz: wpewebkit-2.38.5/Source/WebKit/Shared/WebGPU/WebGPUExtent3D.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(GPU_PROCESS)

#include <optional>
#include <pal/graphics/WebGPU/WebGPUIntegralTypes.h>
#include <variant>
#include <wtf/Vector.h>

namespace WebKit::WebGPU {

struct Extent3DDict {
    PAL::WebGPU::IntegerCoordinate width { 0 };
    PAL::WebGPU::IntegerCoordinate height { 0 };
    PAL::WebGPU::IntegerCoordinate depthOrArrayLayers { 0 };

    template<class Encoder> void encode(Encoder& encoder) const
    {
        encoder << width;
        encoder << height;
        encoder << depthOrArrayLayers;
    }

    template<class Decoder> static std::optional<Extent3DDict> decode(Decoder& decoder)
    {
        std::optional<PAL::WebGPU::IntegerCoordinate> width;
        decoder >> width;
        if (!width)
            return std::nullopt;

        std::optional<PAL::WebGPU::IntegerCoordinate> height;
        decoder >> height;
        if (!height)
            return std::nullopt;

        std::optional<PAL::WebGPU::IntegerCoordinate> depthOrArrayLayers;
        decoder >> depthOrArrayLayers;
        if (!depthOrArrayLayers)
            return std::nullopt;

        return { { WTFMove(*width), WTFMove(*height), WTFMove(*depthOrArrayLayers) } };
    }
};

using Extent3D = std::variant<Vector<PAL::WebGPU::IntegerCoordinate>, Extent3DDict>;

} // namespace WebKit::WebGPU

#endif // ENABLE(GPU_PROCESS)

==> wpewebkit_2.50.1.orig.tar.xz: wpewebkit-2.50.1/Source/WebKit/Shared/WebGPU/WebGPUExtent3D.h <==
/*
 * Copyright (C) 2021-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(GPU_PROCESS)

#include <WebCore/WebGPUIntegralTypes.h>
#include <optional>
#include <wtf/Vector.h>

namespace WebKit::WebGPU {

struct Extent3DDict {
    WebCore::WebGPU::IntegerCoordinate width { 0 };
    WebCore::WebGPU::IntegerCoordinate height { 0 };
    WebCore::WebGPU::IntegerCoordinate depthOrArrayLayers { 0 };
};

using Extent3D = Variant<Vector<WebCore::WebGPU::IntegerCoordinate>, Extent3DDict>;

} // namespace WebKit::WebGPU

#endif // ENABLE(GPU_PROCESS)
